Rdocumentation
powered by
Learn R Programming
searchConsoleR (version 0.1.2)
list_websites: Retrieves dataframe of websites user has in Search Console
Description
Retrieves dataframe of websites user has in Search Console
Usage
list_websites()
Arguments
Value
a dataframe of siteUrl and permissionLevel
See Also
Other search console website functions:
add_website
;
delete_website